@@ -29,7 +29,7 @@ my %libmodperl  = (1 => 'libperl.so', 2 => 'mod_perl.so');
 sub configure_libmodperl {
     my $self = shift;
 
-    my $server = $self->{server};
+    my $server  = $self->{server};
     my $libname = $server->version_of(\%libmodperl);
     my $vars = $self->{vars};
 
@@ -94,10 +94,7 @@ sub configure_libmodperl {
         debug $msg;
     }
 
-    # modules like Embperl.so need mod_perl.so to be loaded first,
-    # so make sure that it's loaded before files inherited from the
-    # global httpd.conf
-    $self->preamble_first(IfModule => '!mod_perl.c', $cfg);
+    $self->preamble(IfModule => '!mod_perl.c', $cfg);
 
 }
 
@@ -183,6 +180,10 @@ sub configure_startup_pl {
             next unless $_;
             print $fh "use lib '$_';\n";
         }
+        my $tlib = catdir $self->{vars}->{t_dir}, 'lib';
+        if (-d $tlib) {
+            print $fh "use lib '$tlib';\n";
+        }
         my $fixup = Apache::TestConfig->modperl_2_inc_fixup();
         print $fh $fixup;
 
